@@ -51,7 +51,11 @@ specificTerms <- function(dtm, variable=NULL, p=0.1, n.max=25, sparsity=0.95, mi
                            .gettext("Level"), .gettext("Global"),
                            .gettext("t value"), .gettext("Prob."))
 
-        ret[order(-sign(ret[, 6]), ret[, 7]), , drop=FALSE]
+        ret <- ret[order(ret[, 6], decreasing=TRUE),]
+        n <- which(ret[,6] < 0)[1]
+        ret <- rbind(ret[1:(n-1),], NA, ret[n:nrow(ret),])
+        rownames(ret)[n] <- strrep("-", max(nchar(rownames(ret), type="width")))
+        ret
     })
 }
 
